# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************

"""
Glacier2 module
"""

import threading, traceback, copy

#
# Import the Python extension.
#
import Ice
Ice.updateModule("Glacier2")

import Glacier2_Router_ice
import Glacier2_Session_ice
import Glacier2_PermissionsVerifier_ice
import Glacier2_SSLInfo_ice
import Glacier2_Metrics_ice

class SessionNotExistException(Exception):
    def __init__(self):
        pass

class RestartSessionException(Exception):
    def __init__(self):
        pass

class ConnectionCallbackI(Ice.ConnectionCallback):
    def __init__(self, app):
        self._app = app

    def heartbeat(self, conn):
        pass

    def closed(self, conn):
        self._app.sessionDestroyed()


class Application(Ice.Application):

    def __init__(self, signalPolicy=0): # HandleSignals=0
        '''The constructor accepts an optional argument indicating
whether to handle signals. The value should be either
Application.HandleSignals (the default) or
Application.NoSignalHandling.
'''

        if type(self) == Application:
            raise RuntimeError("Glacier2.Application is an abstract class")

        Ice.Application.__init__(self, signalPolicy)

        Application._adapter = None
        Application._router = None
        Application._session = None
        Application._createdSession = False
        Application._category = None

    def run(self, args):
        raise RuntimeError('run should not be called on Glacier2.Application - call runWithSession instead')

    def runWithSession(self, args):
        raise RuntimeError('runWithSession() not implemented')

    def createSession(self, args):
        raise RuntimeError('createSession() not implemented')

    def restart(self):
        raise RestartSessionException()

    def sessionDestroyed(self):
        pass

    def router(self):
        return Application._router
    router = classmethod(router)

    def session(self):
        return Application._session
    session = classmethod(session)

    def categoryForClient(self):
        if Application._router == None:
            raise SessionNotExistException()
        return Application._category

    def createCallbackIdentity(self, name):
        return Ice.Identity(name, self.categoryForClient())

    def addWithUUID(self, servant):
        return self.objectAdapter().add(servant, self.createCallbackIdentity(Ice.generateUUID()))

    def objectAdapter(self):
        if Application._router == None:
            raise SessionNotExistException()
        if Application._adapter == None:
            Application._adapter = self.communicator().createObjectAdapterWithRouter("", Application._router)
            Application._adapter.activate()
        return Application._adapter

    def doMainInternal(self, args, initData):
        # Reset internal state variables from Ice.Application. The
        # remainder are reset at the end of this method.
        Ice.Application._callbackInProgress = False
        Ice.Application._destroyed = False
        Ice.Application._interrupted = False

        restart = False
        status = 0

        try:
            Ice.Application._communicator = Ice.initialize(args, initData)

            Application._router = RouterPrx.uncheckedCast(Ice.Application.communicator().getDefaultRouter())
            if Application._router == None:
                Ice.getProcessLogger().error("no glacier2 router configured")
                status = 1
            else:
                #
                # The default is to destroy when a signal is received.
                #
                if Ice.Application._signalPolicy == Ice.Application.HandleSignals:
                    Ice.Application.destroyOnInterrupt()

                # If createSession throws, we're done.
                try:
                    Application._session = self.createSession()
                    Application._createdSession = True
                except Ice.LocalException:
                    Ice.getProcessLogger().error(traceback.format_exc())
                    status = 1

                if Application._createdSession:
                    acmTimeout = 0
                    try:
                        acmTimeout = Application._router.getACMTimeout()
                    except(Ice.OperationNotExistException):
                        pass
                    if acmTimeout <= 0:
                        acmTimeout = Application._router.getSessionTimeout()
                    if acmTimeout > 0:
                        connection = Application._router.ice_getCachedConnection()
                        assert(connection)
                        connection.setACM(acmTimeout, Ice.Unset, Ice.ACMHeartbeat.HeartbeatAlways)
                        connection.setCallback(ConnectionCallbackI(self))
                    Application._category = Application._router.getCategoryForClient()
                    status = self.runWithSession(args)

        # We want to restart on those exceptions which indicate a
        # break down in communications, but not those exceptions that
        # indicate a programming logic error (ie: marshal, protocol
        # failure, etc).
        except(RestartSessionException):
            restart = True
        except(Ice.ConnectionRefusedException, Ice.ConnectionLostException, Ice.UnknownLocalException, \
               Ice.RequestFailedException, Ice.TimeoutException):
            Ice.getProcessLogger().error(traceback.format_exc())
            restart = True
        except:
            Ice.getProcessLogger().error(traceback.format_exc())
            status = 1

        #
        # Don't want any new interrupt and at this point (post-run),
        # it would not make sense to release a held signal to run
        # shutdown or destroy.
        #
        if Ice.Application._signalPolicy == Ice.Application.HandleSignals:
            Ice.Application.ignoreInterrupt()

        Ice.Application._condVar.acquire()
        while Ice.Application._callbackInProgress:
            Ice.Application._condVar.wait()
        if Ice.Application._destroyed:
            Ice.Application._communicator = None
        else:
            Ice.Application._destroyed = True
            #
            # And _communicator != None, meaning will be destroyed
            # next, _destroyed = True also ensures that any
            # remaining callback won't do anything
            #
        Ice.Application._condVar.release()

        if Application._createdSession and Application._router:
            try:
                Application._router.destroySession()
            except (Ice.ConnectionLostException, SessionNotExistException):
                pass
            except:
                Ice.getProcessLogger().error("unexpected exception when destroying the session " + \
                                             traceback.format_exc())
            Application._router = None

        if Ice.Application._communicator:
            try:
                Ice.Application._communicator.destroy()
            except:
                getProcessLogger().error(traceback.format_exc())
                status = 1

            Ice.Application._communicator = None

        # Reset internal state. We cannot reset the Application state
        # here, since _destroyed must remain true until we re-run
        # this method.
        Application._adapter = None
        Application._router = None
        Application._session = None
        Application._createdSession = False
        Application._category = None

        return (restart, status)

    def doMain(self, args, initData):
        # Set the default properties for all Glacier2 applications.
        initData.properties.setProperty("Ice.RetryIntervals", "-1")

        restart = True
        ret = 0
        while restart:
            # A copy of the initialization data and the string seq
            # needs to be passed to doMainInternal, as these can be
            # changed by the application.
            id = copy.copy(initData)
            if id.properties:
                id.properties = id.properties.clone()
            argsCopy = args[:]
            (restart, ret) = self.doMainInternal(argsCopy, initData)
        return ret



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ProcessF.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Ice
_M_Ice = Ice.openModule('Ice')
__name__ = 'Ice'

if 'Process' not in _M_Ice.__dict__:
    _M_Ice._t_Process = IcePy.declareClass('::Ice::Process')
    _M_Ice._t_ProcessPrx = IcePy.declareProxy('::Ice::Process')

# End of module Ice



#!/usr/bin/env python
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************

import sys, Ice, IcePy
def main():
    sliceDir = Ice.getSliceDir()
    # Automatically add the slice dir.
    if not sliceDir is None:
        sys.argv.append('-I' + sliceDir)
    val = IcePy.compile(sys.argv)
    sys.exit(int(val))



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Plugin.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_LoggerF_ice
import Ice_BuiltinSequences_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'Plugin' not in _M_Ice.__dict__:
    _M_Ice.Plugin = Ice.createTempClass()
    class Plugin(object):
        """
        A communicator plug-in. A plug-in generally adds a feature to a
        communicator, such as support for a protocol.
        The communicator loads its plug-ins in two stages: the first stage
        creates the plug-ins, and the second stage invokes Plugin#initialize on
        each one.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Plugin:
                raise RuntimeError('Ice.Plugin is an abstract class')

        def initialize(self):
            """
            Perform any necessary initialization steps.
            """
            pass

        def destroy(self):
            """
            Called when the communicator is being destroyed.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Plugin)

        __repr__ = __str__

    _M_Ice._t_Plugin = IcePy.defineClass('::Ice::Plugin', Plugin, -1, (), True, False, None, (), ())
    Plugin._ice_type = _M_Ice._t_Plugin

    _M_Ice.Plugin = Plugin
    del Plugin

if 'PluginManager' not in _M_Ice.__dict__:
    _M_Ice.PluginManager = Ice.createTempClass()
    class PluginManager(object):
        """
        Each communicator has a plug-in manager to administer the set of
        plug-ins.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.PluginManager:
                raise RuntimeError('Ice.PluginManager is an abstract class')

        def initializePlugins(self):
            """
            Initialize the configured plug-ins. The communicator automatically initializes
            the plug-ins by default, but an application may need to interact directly with
            a plug-in prior to initialization. In this case, the application must set
            Ice.InitPlugins=0 and then invoke initializePlugins
            manually. The plug-ins are initialized in the order in which they are loaded.
            If a plug-in raises an exception during initialization, the communicator
            invokes destroy on the plug-ins that have already been initialized.
            Throws:
            InitializationException -- Raised if the plug-ins have already been initialized.
            """
            pass

        def getPlugins(self):
            """
            Get a list of plugins installed.
            Returns: The names of the plugins installed.
            """
            pass

        def getPlugin(self, name):
            """
            Obtain a plug-in by name.
            Arguments:
            name -- The plug-in's name.
            Returns: The plug-in.
            Throws:
            NotRegisteredException -- Raised if no plug-in is found with the given name.
            """
            pass

        def addPlugin(self, name, pi):
            """
            Install a new plug-in.
            Arguments:
            name -- The plug-in's name.
            pi -- The plug-in.
            Throws:
            AlreadyRegisteredException -- Raised if a plug-in already exists with the given name.
            """
            pass

        def destroy(self):
            """
            Called when the communicator is being destroyed.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_PluginManager)

        __repr__ = __str__

    _M_Ice._t_PluginManager = IcePy.defineClass('::Ice::PluginManager', PluginManager, -1, (), True, False, None, (), ())
    PluginManager._ice_type = _M_Ice._t_PluginManager

    _M_Ice.PluginManager = PluginManager
    del PluginManager

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Communicator.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_LoggerF_ice
import Ice_InstrumentationF_ice
import Ice_ObjectAdapterF_ice
import Ice_ObjectFactoryF_ice
import Ice_RouterF_ice
import Ice_LocatorF_ice
import Ice_PluginF_ice
import Ice_ImplicitContextF_ice
import Ice_Current_ice
import Ice_Properties_ice
import Ice_FacetMap_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Ice.Instrumentation
_M_Ice.Instrumentation = Ice.openModule('Ice.Instrumentation')

# Start of module Ice
__name__ = 'Ice'
_M_Ice.__doc__ = """
The Ice core library. Among many other features, the Ice core
library manages all the communication tasks using an efficient
protocol (including protocol compression and support for both TCP
and UDP), provides a thread pool for multi-threaded servers, and
additional functionality that supports high scalability.
"""

if 'Communicator' not in _M_Ice.__dict__:
    _M_Ice.Communicator = Ice.createTempClass()
    class Communicator(object):
        """
        The central object in Ice. One or more communicators can be
        instantiated for an Ice application. Communicator instantiation
        is language-specific, and not specified in Slice code.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Communicator:
                raise RuntimeError('Ice.Communicator is an abstract class')

        def destroy(self):
            """
            Destroy the communicator. This operation calls shutdown
            implicitly.  Calling destroy cleans up memory, and shuts down
            this communicator's client functionality and destroys all object
            adapters. Subsequent calls to destroy are ignored.
            """
            pass

        def shutdown(self):
            """
            Shuts down this communicator's server functionality, which
            includes the deactivation of all object adapters. (Attempts to use
            a deactivated object adapter raise ObjectAdapterDeactivatedException.)
            Subsequent calls to shutdown are ignored.
             After shutdown returns, no new requests are
            processed. However, requests that have been started before
            shutdown was called might still be active. You can use
            waitForShutdown to wait for the completion of all
            requests.
            """
            pass

        def waitForShutdown(self):
            """
            Wait until the application has called shutdown (or destroy).
            On the server side, this operation blocks the calling thread
            until all currently-executing operations have completed.
            On the client side, the operation simply block until another
            thread has called shutdown or destroy.
            A typical use of this operation is to call it
            from the main thread, which then waits until some other thread
            calls shutdown. After shut-down is complete, the main thread
            returns and can do some cleanup work before it finally calls
            destroy to shut down the client functionality, and then
            exits the application.
            """
            pass

        def isShutdown(self):
            """
            Check whether communicator has been shut down.
            Returns: True if the communicator has been shut down; false otherwise.
            """
            pass

        def stringToProxy(self, str):
            """
            Convert a stringified proxy into a proxy. For example,
            MyCategory/MyObject:tcp -h some_host -p
            10000 creates a proxy that refers to the Ice object
            having an identity with a name "MyObject" and a category
            "MyCategory", with the server running on host "some_host", port
            10000. If the stringified proxy does not parse correctly, the
            operation throws one of ProxyParseException,
            EndpointParseException, or IdentityParseException.
            An appendix in the Ice manual provides a detailed description
            of the syntax supported by stringified proxies.
            Arguments:
            str -- The stringified proxy to convert into a proxy.
            Returns: The proxy, or nil if str is an empty string.
            """
            pass

        def proxyToString(self, obj):
            """
            Convert a proxy into a string.
            Arguments:
            obj -- The proxy to convert into a stringified proxy.
            Returns: The stringified proxy, or an empty string if obj is nil.
            """
            pass

        def propertyToProxy(self, property):
            """
            Convert a set of proxy properties into a proxy. The "base"
            name supplied in the property argument refers to a
            property containing a stringified proxy, such as
            MyProxy=id:tcp -h localhost -p 10000. Additional
            properties configure local settings for the proxy, such as
            MyProxy.PreferSecure=1. The "Properties"
            appendix in the Ice manual describes each of the supported
            proxy properties.
            Arguments:
            property -- The base property name.
            Returns: The proxy.
            """
            pass

        def proxyToProperty(self, proxy, property):
            """
            Convert a proxy to a set of proxy properties.
            Arguments:
            proxy -- The proxy.
            property -- The base property name.
            Returns: The property set.
            """
            pass

        def stringToIdentity(self, str):
            """
            Convert a string into an identity. If the string does not parse
            correctly, the operation throws IdentityParseException.
            Arguments:
            str -- The string to convert into an identity.
            Returns: The identity.
            """
            pass

        def identityToString(self, ident):
            """
            Convert an identity into a string.
            Arguments:
            ident -- The identity to convert into a string.
            Returns: The "stringified" identity.
            """
            pass

        def createObjectAdapter(self, name):
            """
            Create a new object adapter. The endpoints for the object
            adapter are taken from the property name.Endpoints.
            It is legal to create an object adapter with the empty string as
            its name. Such an object adapter is accessible via bidirectional
            connections or by collocated invocations that originate from the
            same communicator as is used by the adapter.
            Attempts to create a named object adapter for which no configuration
            can be found raise InitializationException.
            Arguments:
            name -- The object adapter name.
            Returns: The new object adapter.
            """
            pass

        def createObjectAdapterWithEndpoints(self, name, endpoints):
            """
            Create a new object adapter with endpoints. This operation sets
            the property name.Endpoints,
            and then calls createObjectAdapter. It is provided as a
            convenience function.
            Calling this operation with an empty name will result in a
            UUID being generated for the name.
            Arguments:
            name -- The object adapter name.
            endpoints -- The endpoints for the object adapter.
            Returns: The new object adapter.
            """
            pass

        def createObjectAdapterWithRouter(self, name, rtr):
            """
            Create a new object adapter with a router. This operation
            creates a routed object adapter.
            Calling this operation with an empty name will result in a
            UUID being generated for the name.
            Arguments:
            name -- The object adapter name.
            rtr -- The router.
            Returns: The new object adapter.
            """
            pass

        def addObjectFactory(self, factory, id):
            """
            Add an object factory to this communicator. Installing a
            factory with an id for which a factory is already registered
            throws AlreadyRegisteredException.
            When unmarshaling an Ice object, the Ice run time reads the
            most-derived type id off the wire and attempts to create an
            instance of the type using a factory. If no instance is created,
            either because no factory was found, or because all factories
            returned nil, the behavior of the Ice run time depends on the
            format with which the object was marshaled:
            If the object uses the "sliced" format, Ice ascends the class
            hierarchy until it finds a type that is recognized by a factory,
            or it reaches the least-derived type. If no factory is found that
            can create an instance, the run time throws
            NoObjectFactoryException.
            If the object uses the "compact" format, Ice immediately raises
            NoObjectFactoryException.
            The following order is used to locate a factory for a type:
            The Ice run-time looks for a factory registered
            specifically for the type.
            If no instance has been created, the Ice run-time looks
            for the default factory, which is registered with an empty type id.
            If no instance has been created by any of the preceding
            steps, the Ice run-time looks for a factory that may have been
            statically generated by the language mapping for non-abstract classes.
            Arguments:
            factory -- The factory to add.
            id -- The type id for which the factory can create instances, or an empty string for the default factory.
            """
            pass

        def findObjectFactory(self, id):
            """
            Find an object factory registered with this communicator.
            Arguments:
            id -- The type id for which the factory can create instances, or an empty string for the default factory.
            Returns: The object factory, or null if no object factory was found for the given id.
            """
            pass

        def getImplicitContext(self):
            """
            Get the implicit context associated with this communicator.
            Returns: The implicit context associated with this communicator; returns null when the property Ice.ImplicitContext is not set or is set to None.
            """
            pass

        def getProperties(self):
            """
            Get the properties for this communicator.
            Returns: This communicator's properties.
            """
            pass

        def getLogger(self):
            """
            Get the logger for this communicator.
            Returns: This communicator's logger.
            """
            pass

        def getObserver(self):
            """
            Get the observer resolver object for this communicator.
            Returns: This communicator's observer resolver object.
            """
            pass

        def getDefaultRouter(self):
            """
            Get the default router this communicator.
            Returns: The default router for this communicator.
            """
            pass

        def setDefaultRouter(self, rtr):
            """
            Set a default router for this communicator. All newly
            created proxies will use this default router. To disable the
            default router, null can be used. Note that this
            operation has no effect on existing proxies.
            You can also set a router for an individual proxy
            by calling the operation ice_router on the proxy.
            Arguments:
            rtr -- The default router to use for this communicator.
            """
            pass

        def getDefaultLocator(self):
            """
            Get the default locator this communicator.
            Returns: The default locator for this communicator.
            """
            pass

        def setDefaultLocator(self, loc):
            """
            Set a default Ice locator for this communicator. All newly
            created proxy and object adapters will use this default
            locator. To disable the default locator, null can be used.
            Note that this operation has no effect on existing proxies or
            object adapters.
             You can also set a locator for an individual proxy
            by calling the operation ice_locator on the proxy, or for an
            object adapter by calling the operation ObjectAdapter#setLocator
            on the object adapter.
            Arguments:
            loc -- The default locator to use for this communicator.
            """
            pass

        def getPluginManager(self):
            """
            Get the plug-in manager for this communicator.
            Returns: This communicator's plug-in manager.
            """
            pass

        def flushBatchRequests(self):
            """
            Flush any pending batch requests for this communicator.
            This means all batch requests invoked on fixed proxies
            for all connections associated with the communicator.
            Any errors that occur while flushing a connection are ignored.
            """
            pass

        def createAdmin(self, adminAdapter, adminId):
            """
            Add the Admin object with all its facets to the provided object adapter.
            If Ice.Admin.ServerId is set and the provided object adapter has a Locator,
            createAdmin registers the Admin's Process facet with the Locator's LocatorRegistry.
            createAdmin call only be called once; subsequent calls raise InitializationException.
            Arguments:
            adminAdapter -- The object adapter used to host the Admin object; if null and Ice.Admin.Endpoints is set, create, activate and use the Ice.Admin object adapter.
            adminId -- The identity of the Admin object.
            Returns: A proxy to the main ("") facet of the Admin object. Never returns a null proxy.
            """
            pass

        def getAdmin(self):
            """
            Get a proxy to the main facet of the Admin object.
            getAdmin also creates the Admin object and creates and activates the Ice.Admin object
            adapter to host this Admin object if Ice.Admin.Enpoints is set. The identity of the Admin
            object created by getAdmin is /admin, or /admin
            when Ice.Admin.InstanceName is not set.
            If Ice.Admin.DelayCreation is 0 or not set, getAdmin is called by the communicator
            initialization, after initialization of all plugins.
            Returns: A proxy to the main ("") facet of the Admin object, or a null proxy if no Admin object is configured.
            """
            pass

        def addAdminFacet(self, servant, facet):
            """
            Add a new facet to the Admin object.
            Adding a servant with a facet that is already registered
            throws AlreadyRegisteredException.
            Arguments:
            servant -- The servant that implements the new Admin facet.
            facet -- The name of the new Admin facet.
            """
            pass

        def removeAdminFacet(self, facet):
            """
            Remove the following facet to the Admin object.
            Removing a facet that was not previously registered throws
            NotRegisteredException.
            Arguments:
            facet -- The name of the Admin facet.
            Returns: The servant associated with this Admin facet.
            """
            pass

        def findAdminFacet(self, facet):
            """
            Returns a facet of the Admin object.
            Arguments:
            facet -- The name of the Admin facet.
            Returns: The servant associated with this Admin facet, or null if no facet is registered with the given name.
            """
            pass

        def findAllAdminFacets(self):
            """
            Returns a map of all facets of the Admin object.
            Returns: A collection containing all the facet names and servants of the Admin object.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Communicator)

        __repr__ = __str__

    _M_Ice._t_Communicator = IcePy.defineClass('::Ice::Communicator', Communicator, -1, (), True, False, None, (), ())
    Communicator._ice_type = _M_Ice._t_Communicator

    _M_Ice.Communicator = Communicator
    del Communicator

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Endpoint.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_Version_ice
import Ice_BuiltinSequences_ice
import Ice_EndpointF_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

_M_Ice.TCPEndpointType = 1

_M_Ice.SSLEndpointType = 2

_M_Ice.UDPEndpointType = 3

_M_Ice.WSEndpointType = 4

_M_Ice.WSSEndpointType = 5

if 'EndpointInfo' not in _M_Ice.__dict__:
    _M_Ice.EndpointInfo = Ice.createTempClass()
    class EndpointInfo(object):
        """
        Base class providing access to the endpoint details.
        Members:
        timeout -- The timeout for the endpoint in milliseconds. 0 means
        non-blocking, -1 means no timeout.
        compress -- Specifies whether or not compression should be used if
        available when using this endpoint.
        """
        def __init__(self, timeout=0, compress=False):
            if Ice.getType(self) == _M_Ice.EndpointInfo:
                raise RuntimeError('Ice.EndpointInfo is an abstract class')
            self.timeout = timeout
            self.compress = compress

        def type(self):
            """
            Returns the type of the endpoint.
            """
            pass

        def datagram(self):
            """
            Returns true if this endpoint is a datagram endpoint.
            """
            pass

        def secure(self):
            """
            Returns true if this endpoint is a secure endpoint.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_EndpointInfo)

        __repr__ = __str__

    _M_Ice._t_EndpointInfo = IcePy.defineClass('::Ice::EndpointInfo', EndpointInfo, -1, (), True, False, None, (), (
        ('timeout', (), IcePy._t_int, False, 0),
        ('compress', (), IcePy._t_bool, False, 0)
    ))
    EndpointInfo._ice_type = _M_Ice._t_EndpointInfo

    _M_Ice.EndpointInfo = EndpointInfo
    del EndpointInfo

if 'Endpoint' not in _M_Ice.__dict__:
    _M_Ice.Endpoint = Ice.createTempClass()
    class Endpoint(object):
        """
        The user-level interface to an endpoint.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Endpoint:
                raise RuntimeError('Ice.Endpoint is an abstract class')

        def toString(self):
            """
            Return a string representation of the endpoint.
            Returns: The string representation of the endpoint.
            """
            pass

        def getInfo(self):
            """
            Returns the endpoint information.
            Returns: The endpoint information class.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Endpoint)

        __repr__ = __str__

    _M_Ice._t_Endpoint = IcePy.defineClass('::Ice::Endpoint', Endpoint, -1, (), True, False, None, (), ())
    Endpoint._ice_type = _M_Ice._t_Endpoint

    _M_Ice.Endpoint = Endpoint
    del Endpoint

if 'IPEndpointInfo' not in _M_Ice.__dict__:
    _M_Ice.IPEndpointInfo = Ice.createTempClass()
    class IPEndpointInfo(_M_Ice.EndpointInfo):
        """
        Provides access to the address details of a IP endpoint.
        Members:
        host -- The host or address configured with the endpoint.
        port -- The port number.
        sourceAddress -- The source IP address.
        """
        def __init__(self, timeout=0, compress=False, host='', port=0, sourceAddress=''):
            if Ice.getType(self) == _M_Ice.IPEndpointInfo:
                raise RuntimeError('Ice.IPEndpointInfo is an abstract class')
            _M_Ice.EndpointInfo.__init__(self, timeout, compress)
            self.host = host
            self.port = port
            self.sourceAddress = sourceAddress

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_IPEndpointInfo)

        __repr__ = __str__

    _M_Ice._t_IPEndpointInfo = IcePy.defineClass('::Ice::IPEndpointInfo', IPEndpointInfo, -1, (), True, False, _M_Ice._t_EndpointInfo, (), (
        ('host', (), IcePy._t_string, False, 0),
        ('port', (), IcePy._t_int, False, 0),
        ('sourceAddress', (), IcePy._t_string, False, 0)
    ))
    IPEndpointInfo._ice_type = _M_Ice._t_IPEndpointInfo

    _M_Ice.IPEndpointInfo = IPEndpointInfo
    del IPEndpointInfo

if 'TCPEndpointInfo' not in _M_Ice.__dict__:
    _M_Ice.TCPEndpointInfo = Ice.createTempClass()
    class TCPEndpointInfo(_M_Ice.IPEndpointInfo):
        """
        Provides access to a TCP endpoint information.
        """
        def __init__(self, timeout=0, compress=False, host='', port=0, sourceAddress=''):
            if Ice.getType(self) == _M_Ice.TCPEndpointInfo:
                raise RuntimeError('Ice.TCPEndpointInfo is an abstract class')
            _M_Ice.IPEndpointInfo.__init__(self, timeout, compress, host, port, sourceAddress)

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_TCPEndpointInfo)

        __repr__ = __str__

    _M_Ice._t_TCPEndpointInfo = IcePy.defineClass('::Ice::TCPEndpointInfo', TCPEndpointInfo, -1, (), True, False, _M_Ice._t_IPEndpointInfo, (), ())
    TCPEndpointInfo._ice_type = _M_Ice._t_TCPEndpointInfo

    _M_Ice.TCPEndpointInfo = TCPEndpointInfo
    del TCPEndpointInfo

if 'UDPEndpointInfo' not in _M_Ice.__dict__:
    _M_Ice.UDPEndpointInfo = Ice.createTempClass()
    class UDPEndpointInfo(_M_Ice.IPEndpointInfo):
        """
        Provides access to an UDP endpoint information.
        Members:
        mcastInterface -- The multicast interface.
        mcastTtl -- The multicast time-to-live (or hops).
        """
        def __init__(self, timeout=0, compress=False, host='', port=0, sourceAddress='', mcastInterface='', mcastTtl=0):
            if Ice.getType(self) == _M_Ice.UDPEndpointInfo:
                raise RuntimeError('Ice.UDPEndpointInfo is an abstract class')
            _M_Ice.IPEndpointInfo.__init__(self, timeout, compress, host, port, sourceAddress)
            self.mcastInterface = mcastInterface
            self.mcastTtl = mcastTtl

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_UDPEndpointInfo)

        __repr__ = __str__

    _M_Ice._t_UDPEndpointInfo = IcePy.defineClass('::Ice::UDPEndpointInfo', UDPEndpointInfo, -1, (), True, False, _M_Ice._t_IPEndpointInfo, (), (
        ('mcastInterface', (), IcePy._t_string, False, 0),
        ('mcastTtl', (), IcePy._t_int, False, 0)
    ))
    UDPEndpointInfo._ice_type = _M_Ice._t_UDPEndpointInfo

    _M_Ice.UDPEndpointInfo = UDPEndpointInfo
    del UDPEndpointInfo

if 'WSEndpointInfo' not in _M_Ice.__dict__:
    _M_Ice.WSEndpointInfo = Ice.createTempClass()
    class WSEndpointInfo(_M_Ice.TCPEndpointInfo):
        """
        Provides access to a WebSocket endpoint information.
        Members:
        resource -- The URI configured with the endpoint.
        """
        def __init__(self, timeout=0, compress=False, host='', port=0, sourceAddress='', resource=''):
            if Ice.getType(self) == _M_Ice.WSEndpointInfo:
                raise RuntimeError('Ice.WSEndpointInfo is an abstract class')
            _M_Ice.TCPEndpointInfo.__init__(self, timeout, compress, host, port, sourceAddress)
            self.resource = resource

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_WSEndpointInfo)

        __repr__ = __str__

    _M_Ice._t_WSEndpointInfo = IcePy.defineClass('::Ice::WSEndpointInfo', WSEndpointInfo, -1, (), True, False, _M_Ice._t_TCPEndpointInfo, (), (('resource', (), IcePy._t_string, False, 0),))
    WSEndpointInfo._ice_type = _M_Ice._t_WSEndpointInfo

    _M_Ice.WSEndpointInfo = WSEndpointInfo
    del WSEndpointInfo

if 'OpaqueEndpointInfo' not in _M_Ice.__dict__:
    _M_Ice.OpaqueEndpointInfo = Ice.createTempClass()
    class OpaqueEndpointInfo(_M_Ice.EndpointInfo):
        """
        Provides access to the details of an opaque endpoint.
        Members:
        rawEncoding -- The encoding version of the opaque endpoint (to decode or
        encode the rawBytes).
        rawBytes -- The raw encoding of the opaque endpoint.
        """
        def __init__(self, timeout=0, compress=False, rawEncoding=Ice._struct_marker, rawBytes=None):
            if Ice.getType(self) == _M_Ice.OpaqueEndpointInfo:
                raise RuntimeError('Ice.OpaqueEndpointInfo is an abstract class')
            _M_Ice.EndpointInfo.__init__(self, timeout, compress)
            if rawEncoding is Ice._struct_marker:
                self.rawEncoding = _M_Ice.EncodingVersion()
            else:
                self.rawEncoding = rawEncoding
            self.rawBytes = rawBytes

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_OpaqueEndpointInfo)

        __repr__ = __str__

    _M_Ice._t_OpaqueEndpointInfo = IcePy.defineClass('::Ice::OpaqueEndpointInfo', OpaqueEndpointInfo, -1, (), True, False, _M_Ice._t_EndpointInfo, (), (
        ('rawEncoding', (), _M_Ice._t_EncodingVersion, False, 0),
        ('rawBytes', (), _M_Ice._t_ByteSeq, False, 0)
    ))
    OpaqueEndpointInfo._ice_type = _M_Ice._t_OpaqueEndpointInfo

    _M_Ice.OpaqueEndpointInfo = OpaqueEndpointInfo
    del OpaqueEndpointInfo

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `FileServer.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import IcePatch2_FileInfo_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module IcePatch2
_M_IcePatch2 = Ice.openModule('IcePatch2')

# Start of module IcePatch2
__name__ = 'IcePatch2'
_M_IcePatch2.__doc__ = """
IcePatch can be used to update file hierarchies in a simple and
efficient manner. Checksums ensure file integrity, and data is
compressed before downloading.
"""

if '_t_ByteSeqSeq' not in _M_IcePatch2.__dict__:
    _M_IcePatch2._t_ByteSeqSeq = IcePy.defineSequence('::IcePatch2::ByteSeqSeq', (), _M_Ice._t_ByteSeq)

if 'PartitionOutOfRangeException' not in _M_IcePatch2.__dict__:
    _M_IcePatch2.PartitionOutOfRangeException = Ice.createTempClass()
    class PartitionOutOfRangeException(Ice.UserException):
        """
        A partition argument for was not in the range 0-255.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'IcePatch2::PartitionOutOfRangeException'

    _M_IcePatch2._t_PartitionOutOfRangeException = IcePy.defineException('::IcePatch2::PartitionOutOfRangeException', PartitionOutOfRangeException, (), False, None, ())
    PartitionOutOfRangeException._ice_type = _M_IcePatch2._t_PartitionOutOfRangeException

    _M_IcePatch2.PartitionOutOfRangeException = PartitionOutOfRangeException
    del PartitionOutOfRangeException

if 'FileAccessException' not in _M_IcePatch2.__dict__:
    _M_IcePatch2.FileAccessException = Ice.createTempClass()
    class FileAccessException(Ice.UserException):
        """
        This exception is raised if a file's contents cannot be read.
        Members:
        reason -- An explanation of the reason for the failure.
        """
        def __init__(self, reason=''):
            self.reason = reason

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'IcePatch2::FileAccessException'

    _M_IcePatch2._t_FileAccessException = IcePy.defineException('::IcePatch2::FileAccessException', FileAccessException, (), False, None, (('reason', (), IcePy._t_string, False, 0),))
    FileAccessException._ice_type = _M_IcePatch2._t_FileAccessException

    _M_IcePatch2.FileAccessException = FileAccessException
    del FileAccessException

if 'FileSizeRangeException' not in _M_IcePatch2.__dict__:
    _M_IcePatch2.FileSizeRangeException = Ice.createTempClass()
    class FileSizeRangeException(_M_IcePatch2.FileAccessException):
        """
        This exception is raised if an operation tries to use a file whose size is
        larger than 2.1 GB. Use the "large" versions of the operations instead.
        """
        def __init__(self, reason=''):
            _M_IcePatch2.FileAccessException.__init__(self, reason)

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'IcePatch2::FileSizeRangeException'

    _M_IcePatch2._t_FileSizeRangeException = IcePy.defineException('::IcePatch2::FileSizeRangeException', FileSizeRangeException, (), False, _M_IcePatch2._t_FileAccessException, ())
    FileSizeRangeException._ice_type = _M_IcePatch2._t_FileSizeRangeException

    _M_IcePatch2.FileSizeRangeException = FileSizeRangeException
    del FileSizeRangeException

if 'FileServer' not in _M_IcePatch2.__dict__:
    _M_IcePatch2.FileServer = Ice.createTempClass()
    class FileServer(Ice.Object):
        """
        The interface that provides access to files.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IcePatch2.FileServer:
                raise RuntimeError('IcePatch2.FileServer is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IcePatch2::FileServer')

        def ice_id(self, current=None):
            return '::IcePatch2::FileServer'

        def ice_staticId():
            return '::IcePatch2::FileServer'
        ice_staticId = staticmethod(ice_staticId)

        def getFileInfoSeq(self, partition, current=None):
            """
            Return file information for the specified partition.
             This operation is deprecated and only present for
            compatibility with old Ice clients (older than version 3.6).
            Arguments:
            partition -- The partition number in the range 0-255.
            current -- The Current object for the invocation.
            Returns: A sequence containing information about the files in the specified partition.
            Throws:
            FileSizeRangeException -- If a file is larger than 2.1GB.
            PartitionOutOfRangeException -- If the partition number is out of range.
            """
            pass

        def getLargeFileInfoSeq(self, partition, current=None):
            """
            Returns file information for the specified partition.
            Arguments:
            partition -- The partition number in the range 0-255.
            current -- The Current object for the invocation.
            Returns: A sequence containing information about the files in the specified partition.
            Throws:
            PartitionOutOfRangeException -- If the partition number is out of range.
            """
            pass

        def getChecksumSeq(self, current=None):
            """
            Return the checksums for all partitions.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A sequence containing 256 checksums. Partitions with a checksum that differs from the previous checksum for the same partition contain updated files. Partitions with a checksum that is identical to the previous checksum do not contain updated files.
            """
            pass

        def getChecksum(self, current=None):
            """
            Return the master checksum for all partitions. If this checksum is the same
            as for a previous run, the entire file set is up-to-date.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The master checksum for the file set.
            """
            pass

        def getFileCompressed_async(self, _cb, path, pos, num, current=None):
            """
            Read the specified file. This operation may only return fewer bytes than requested
            in case there was an end-of-file condition.
             This operation is deprecated and only present for
            compatibility with old Ice clients (older than version 3.6).
            Arguments:
            _cb -- The asynchronous callback object.
            path -- The pathname (relative to the data directory) for the file to be read.
            pos -- The file offset at which to begin reading.
            num -- The number of bytes to be read.
            current -- The Current object for the invocation.
            Throws:
            FileAccessException -- If an error occurred while trying to read the file.
            FileSizeRangeException -- If a file is larger than 2.1GB.
            """
            pass

        def getLargeFileCompressed_async(self, _cb, path, pos, num, current=None):
            """
            Read the specified file. This operation may only return fewer bytes than requested
            in case there was an end-of-file condition.
            Arguments:
            _cb -- The asynchronous callback object.
            path -- The pathname (relative to the data directory) for the file to be read.
            pos -- The file offset at which to begin reading.
            num -- The number of bytes to be read.
            current -- The Current object for the invocation.
            Throws:
            FileAccessException -- If an error occurred while trying to read the file.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IcePatch2._t_FileServer)

        __repr__ = __str__

    _M_IcePatch2.FileServerPrx = Ice.createTempClass()
    class FileServerPrx(Ice.ObjectPrx):

        """
        Return file information for the specified partition.
         This operation is deprecated and only present for
        compatibility with old Ice clients (older than version 3.6).
        Arguments:
        partition -- The partition number in the range 0-255.
        _ctx -- The request context for the invocation.
        Returns: A sequence containing information about the files in the specified partition.
        Throws:
        FileSizeRangeException -- If a file is larger than 2.1GB.
        PartitionOutOfRangeException -- If the partition number is out of range.
        """
        def getFileInfoSeq(self, partition, _ctx=None):
            return _M_IcePatch2.FileServer._op_getFileInfoSeq.invoke(self, ((partition, ), _ctx))

        """
        Return file information for the specified partition.
         This operation is deprecated and only present for
        compatibility with old Ice clients (older than version 3.6).
        Arguments:
        partition -- The partition number in the range 0-255.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getFileInfoSeq(self, partition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IcePatch2.FileServer._op_getFileInfoSeq.begin(self, ((partition, ), _response, _ex, _sent, _ctx))

        """
        Return file information for the specified partition.
         This operation is deprecated and only present for
        compatibility with old Ice clients (older than version 3.6).
        Arguments:
        partition -- The partition number in the range 0-255.
        Returns: A sequence containing information about the files in the specified partition.
        Throws:
        FileSizeRangeException -- If a file is larger than 2.1GB.
        PartitionOutOfRangeException -- If the partition number is out of range.
        """
        def end_getFileInfoSeq(self, _r):
            return _M_IcePatch2.FileServer._op_getFileInfoSeq.end(self, _r)

        """
        Returns file information for the specified partition.
        Arguments:
        partition -- The partition number in the range 0-255.
        _ctx -- The request context for the invocation.
        Returns: A sequence containing information about the files in the specified partition.
        Throws:
        PartitionOutOfRangeException -- If the partition number is out of range.
        """
        def getLargeFileInfoSeq(self, partition, _ctx=None):
            return _M_IcePatch2.FileServer._op_getLargeFileInfoSeq.invoke(self, ((partition, ), _ctx))

        """
        Returns file information for the specified partition.
        Arguments:
        partition -- The partition number in the range 0-255.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getLargeFileInfoSeq(self, partition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IcePatch2.FileServer._op_getLargeFileInfoSeq.begin(self, ((partition, ), _response, _ex, _sent, _ctx))

        """
        Returns file information for the specified partition.
        Arguments:
        partition -- The partition number in the range 0-255.
        Returns: A sequence containing information about the files in the specified partition.
        Throws:
        PartitionOutOfRangeException -- If the partition number is out of range.
        """
        def end_getLargeFileInfoSeq(self, _r):
            return _M_IcePatch2.FileServer._op_getLargeFileInfoSeq.end(self, _r)

        """
        Return the checksums for all partitions.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: A sequence containing 256 checksums. Partitions with a checksum that differs from the previous checksum for the same partition contain updated files. Partitions with a checksum that is identical to the previous checksum do not contain updated files.
        """
        def getChecksumSeq(self, _ctx=None):
            return _M_IcePatch2.FileServer._op_getChecksumSeq.invoke(self, ((), _ctx))

        """
        Return the checksums for all partitions.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getChecksumSeq(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IcePatch2.FileServer._op_getChecksumSeq.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Return the checksums for all partitions.
        Arguments:
        Returns: A sequence containing 256 checksums. Partitions with a checksum that differs from the previous checksum for the same partition contain updated files. Partitions with a checksum that is identical to the previous checksum do not contain updated files.
        """
        def end_getChecksumSeq(self, _r):
            return _M_IcePatch2.FileServer._op_getChecksumSeq.end(self, _r)

        """
        Return the master checksum for all partitions. If this checksum is the same
        as for a previous run, the entire file set is up-to-date.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The master checksum for the file set.
        """
        def getChecksum(self, _ctx=None):
            return _M_IcePatch2.FileServer._op_getChecksum.invoke(self, ((), _ctx))

        """
        Return the master checksum for all partitions. If this checksum is the same
        as for a previous run, the entire file set is up-to-date.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getChecksum(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IcePatch2.FileServer._op_getChecksum.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Return the master checksum for all partitions. If this checksum is the same
        as for a previous run, the entire file set is up-to-date.
        Arguments:
        Returns: The master checksum for the file set.
        """
        def end_getChecksum(self, _r):
            return _M_IcePatch2.FileServer._op_getChecksum.end(self, _r)

        """
        Read the specified file. This operation may only return fewer bytes than requested
        in case there was an end-of-file condition.
         This operation is deprecated and only present for
        compatibility with old Ice clients (older than version 3.6).
        Arguments:
        path -- The pathname (relative to the data directory) for the file to be read.
        pos -- The file offset at which to begin reading.
        num -- The number of bytes to be read.
        _ctx -- The request context for the invocation.
        Returns: A sequence containing the compressed file contents.
        Throws:
        FileAccessException -- If an error occurred while trying to read the file.
        FileSizeRangeException -- If a file is larger than 2.1GB.
        """
        def getFileCompressed(self, path, pos, num, _ctx=None):
            return _M_IcePatch2.FileServer._op_getFileCompressed.invoke(self, ((path, pos, num), _ctx))

        """
        Read the specified file. This operation may only return fewer bytes than requested
        in case there was an end-of-file condition.
         This operation is deprecated and only present for
        compatibility with old Ice clients (older than version 3.6).
        Arguments:
        path -- The pathname (relative to the data directory) for the file to be read.
        pos -- The file offset at which to begin reading.
        num -- The number of bytes to be read.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getFileCompressed(self, path, pos, num, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IcePatch2.FileServer._op_getFileCompressed.begin(self, ((path, pos, num), _response, _ex, _sent, _ctx))

        """
        Read the specified file. This operation may only return fewer bytes than requested
        in case there was an end-of-file condition.
         This operation is deprecated and only present for
        compatibility with old Ice clients (older than version 3.6).
        Arguments:
        path -- The pathname (relative to the data directory) for the file to be read.
        pos -- The file offset at which to begin reading.
        num -- The number of bytes to be read.
        Returns: A sequence containing the compressed file contents.
        Throws:
        FileAccessException -- If an error occurred while trying to read the file.
        FileSizeRangeException -- If a file is larger than 2.1GB.
        """
        def end_getFileCompressed(self, _r):
            return _M_IcePatch2.FileServer._op_getFileCompressed.end(self, _r)

        """
        Read the specified file. This operation may only return fewer bytes than requested
        in case there was an end-of-file condition.
        Arguments:
        path -- The pathname (relative to the data directory) for the file to be read.
        pos -- The file offset at which to begin reading.
        num -- The number of bytes to be read.
        _ctx -- The request context for the invocation.
        Returns: A sequence containing the compressed file contents.
        Throws:
        FileAccessException -- If an error occurred while trying to read the file.
        """
        def getLargeFileCompressed(self, path, pos, num, _ctx=None):
            return _M_IcePatch2.FileServer._op_getLargeFileCompressed.invoke(self, ((path, pos, num), _ctx))

        """
        Read the specified file. This operation may only return fewer bytes than requested
        in case there was an end-of-file condition.
        Arguments:
        path -- The pathname (relative to the data directory) for the file to be read.
        pos -- The file offset at which to begin reading.
        num -- The number of bytes to be read.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getLargeFileCompressed(self, path, pos, num, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IcePatch2.FileServer._op_getLargeFileCompressed.begin(self, ((path, pos, num), _response, _ex, _sent, _ctx))

        """
        Read the specified file. This operation may only return fewer bytes than requested
        in case there was an end-of-file condition.
        Arguments:
        path -- The pathname (relative to the data directory) for the file to be read.
        pos -- The file offset at which to begin reading.
        num -- The number of bytes to be read.
        Returns: A sequence containing the compressed file contents.
        Throws:
        FileAccessException -- If an error occurred while trying to read the file.
        """
        def end_getLargeFileCompressed(self, _r):
            return _M_IcePatch2.FileServer._op_getLargeFileCompressed.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IcePatch2.FileServerPrx.ice_checkedCast(proxy, '::IcePatch2::FileServer', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IcePatch2.FileServerPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IcePatch2::FileServer'
        ice_staticId = staticmethod(ice_staticId)

    _M_IcePatch2._t_FileServerPrx = IcePy.defineProxy('::IcePatch2::FileServer', FileServerPrx)

    _M_IcePatch2._t_FileServer = IcePy.defineClass('::IcePatch2::FileServer', FileServer, -1, (), True, False, None, (), ())
    FileServer._ice_type = _M_IcePatch2._t_FileServer

    FileServer._op_getFileInfoSeq = IcePy.Operation('getFileInfoSeq', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_IcePatch2._t_FileInfoSeq, False, 0), (_M_IcePatch2._t_PartitionOutOfRangeException, _M_IcePatch2._t_FileSizeRangeException))
    FileServer._op_getFileInfoSeq.deprecate("getFileInfoSeq() is deprecated, use getLargeFileInfoSeq() instead.")
    FileServer._op_getLargeFileInfoSeq = IcePy.Operation('getLargeFileInfoSeq', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_IcePatch2._t_LargeFileInfoSeq, False, 0), (_M_IcePatch2._t_PartitionOutOfRangeException,))
    FileServer._op_getChecksumSeq = IcePy.Operation('getChecksumSeq', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), _M_IcePatch2._t_ByteSeqSeq, False, 0), ())
    FileServer._op_getChecksum = IcePy.Operation('getChecksum', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), _M_Ice._t_ByteSeq, False, 0), ())
    FileServer._op_getFileCompressed = IcePy.Operation('getFileCompressed', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_int, False, 0), ((), IcePy._t_int, False, 0)), (), ((), _M_Ice._t_ByteSeq, False, 0), (_M_IcePatch2._t_FileAccessException, _M_IcePatch2._t_FileSizeRangeException))
    FileServer._op_getFileCompressed.deprecate("getFileCompressed() is deprecated, use getLargeFileCompressed() instead.")
    FileServer._op_getLargeFileCompressed = IcePy.Operation('getLargeFileCompressed', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_int, False, 0)), (), ((), _M_Ice._t_ByteSeq, False, 0), (_M_IcePatch2._t_FileAccessException,))

    _M_IcePatch2.FileServer = FileServer
    del FileServer

    _M_IcePatch2.FileServerPrx = FileServerPrx
    del FileServerPrx

# End of module IcePatch2

Ice.sliceChecksums["::IcePatch2::ByteSeqSeq"] = "4bef9684e41babda8aa55f759a854c"
Ice.sliceChecksums["::IcePatch2::FileAccessException"] = "e94ba15e1b6a3639c2358d2f384648"
Ice.sliceChecksums["::IcePatch2::FileServer"] = "4e2d29a4d5995edae6405e69b265943b"
Ice.sliceChecksums["::IcePatch2::FileSizeRangeException"] = "24ba4c71f6441c58b23a2058cd776c8"
Ice.sliceChecksums["::IcePatch2::PartitionOutOfRangeException"] = "edd324eb399a3f6fecc1a28c2296d8"
